@@ -3,7 +3,7 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 our @EXPORT = qw(all_vars_ok test_vars vars_ok);
 
@@ -244,7 +244,7 @@ my $op_enteriter;
 my $op_entereval; # string eval
 my @op_svusers;
 BEGIN{
-    foreach my $op(qw(padsv padav padhv multideref)){
+    foreach my $op(qw(padsv padav padhv pp_match multideref)){
         $padops[B::opnumber($op)]++;
     }
     # blead commit 93bad3fd55489cbd split aelemfast into two ops.
@@ -429,7 +429,7 @@ Test::Vars - Detects unused variables in perl modules
 
 =head1 VERSION
 
-This document describes Test::Vars version 0.009.
+This document describes Test::Vars version 0.010.
 
 =head1 SYNOPSIS
 
